# db-connect

`db-connect` is a Python package that provides operations for creating connections and performing CRUD operations on MongoDB and MySQL databases.

## Features

- Connect to MongoDB and MySQL databases
- Insert single or multiple records
- Find records
- Delete records
- Update records
- Bulk insert from CSV or Excel files

## Installation

You can install the package via pip:

pip install danny-db-connect

## 

